"""this is Tools"""
"""by LTPLAX"""
"""version 0.1.0"""
"""Please use Tools.init before use"""
from .music import music
from .flush import flush
from .log import log
__all__=["music","flush","log"]

def init():
    print("LTPpyTools 0.1 Normal mode ready(this ver only have music\ntype:Tools.music.init())")



